diff --git a/core/.eslintrc.passing.json b/core/.eslintrc.passing.json
index 104286667a..fd77adab69 100644
--- a/core/.eslintrc.passing.json
+++ b/core/.eslintrc.passing.json
@@ -13,7 +13,6 @@
     "new-cap": "off",
     "max-len": "off",
     "default-case": "off",
-    "camelcase": "off",
     "vars-on-top": "off",
     "prefer-rest-params": "off"
   }
diff --git a/core/misc/ajax.js b/core/misc/ajax.js
index 955cf12d22..2e6b4f3c84 100644
--- a/core/misc/ajax.js
+++ b/core/misc/ajax.js
@@ -10,14 +10,14 @@ function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr
   Drupal.behaviors.AJAX = {
     attach: function attach(context, settings) {
       function loadAjaxBehavior(base) {
-        var element_settings = settings.ajax[base];
-        if (typeof element_settings.selector === 'undefined') {
-          element_settings.selector = '#' + base;
+        var elementSettings = settings.ajax[base];
+        if (typeof elementSettings.selector === 'undefined') {
+          elementSettings.selector = '#' + base;
         }
-        $(element_settings.selector).once('drupal-ajax').each(function () {
-          element_settings.element = this;
-          element_settings.base = base;
-          Drupal.ajax(element_settings);
+        $(elementSettings.selector).once('drupal-ajax').each(function () {
+          elementSettings.element = this;
+          elementSettings.base = base;
+          Drupal.ajax(elementSettings);
         });
       }
 
@@ -28,37 +28,37 @@ function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr
       }
 
       $('.use-ajax').once('ajax').each(function () {
-        var element_settings = {};
+        var elementSettings = {};
 
-        element_settings.progress = { type: 'throbber' };
+        elementSettings.progress = { type: 'throbber' };
 
         var href = $(this).attr('href');
         if (href) {
-          element_settings.url = href;
-          element_settings.event = 'click';
+          elementSettings.url = href;
+          elementSettings.event = 'click';
         }
-        element_settings.dialogType = $(this).data('dialog-type');
-        element_settings.dialogRenderer = $(this).data('dialog-renderer');
-        element_settings.dialog = $(this).data('dialog-options');
-        element_settings.base = $(this).attr('id');
-        element_settings.element = this;
-        Drupal.ajax(element_settings);
+        elementSettings.dialogType = $(this).data('dialog-type');
+        elementSettings.dialogRenderer = $(this).data('dialog-renderer');
+        elementSettings.dialog = $(this).data('dialog-options');
+        elementSettings.base = $(this).attr('id');
+        elementSettings.element = this;
+        Drupal.ajax(elementSettings);
       });
 
       $('.use-ajax-submit').once('ajax').each(function () {
-        var element_settings = {};
+        var elementSettings = {};
 
-        element_settings.url = $(this.form).attr('action');
+        elementSettings.url = $(this.form).attr('action');
 
-        element_settings.setClick = true;
+        elementSettings.setClick = true;
 
-        element_settings.event = 'click';
+        elementSettings.event = 'click';
 
-        element_settings.progress = { type: 'throbber' };
-        element_settings.base = $(this).attr('id');
-        element_settings.element = this;
+        elementSettings.progress = { type: 'throbber' };
+        elementSettings.base = $(this).attr('id');
+        elementSettings.element = this;
 
-        Drupal.ajax(element_settings);
+        Drupal.ajax(elementSettings);
       });
     },
     detach: function detach(context, settings, trigger) {
@@ -137,7 +137,7 @@ function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr
     });
   };
 
-  Drupal.Ajax = function (base, element, element_settings) {
+  Drupal.Ajax = function (base, element, elementSettings) {
     var defaults = {
       event: element ? 'mousedown' : null,
       keypress: true,
@@ -154,7 +154,7 @@ function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr
       }
     };
 
-    $.extend(this, defaults, element_settings);
+    $.extend(this, defaults, elementSettings);
 
     this.commands = new Drupal.AjaxCommands();
 
@@ -166,7 +166,7 @@ function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr
 
     this.element = element;
 
-    this.element_settings = element_settings;
+    this.elementSettings = elementSettings;
 
     if (this.element && this.element.form) {
       this.$form = $(this.element.form);
@@ -194,12 +194,12 @@ function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr
     ajax.options = {
       url: ajax.url,
       data: ajax.submit,
-      beforeSerialize: function beforeSerialize(element_settings, options) {
-        return ajax.beforeSerialize(element_settings, options);
+      beforeSerialize: function beforeSerialize(elementSettings, options) {
+        return ajax.beforeSerialize(elementSettings, options);
       },
-      beforeSubmit: function beforeSubmit(form_values, element_settings, options) {
+      beforeSubmit: function beforeSubmit(formValues, elementSettings, options) {
         ajax.ajaxing = true;
-        return ajax.beforeSubmit(form_values, element_settings, options);
+        return ajax.beforeSubmit(formValues, elementSettings, options);
       },
       beforeSend: function beforeSend(xmlhttprequest, options) {
         ajax.ajaxing = true;
@@ -230,8 +230,8 @@ function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr
       type: 'POST'
     };
 
-    if (element_settings.dialog) {
-      ajax.options.data.dialogOptions = element_settings.dialog;
+    if (elementSettings.dialog) {
+      ajax.options.data.dialogOptions = elementSettings.dialog;
     }
 
     if (ajax.options.url.indexOf('?') === -1) {
@@ -240,27 +240,27 @@ function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr
       ajax.options.url += '&';
     }
 
-    var wrapper = 'drupal_' + (element_settings.dialogType || 'ajax');
-    if (element_settings.dialogRenderer) {
-      wrapper += '.' + element_settings.dialogRenderer;
+    var wrapper = 'drupal_' + (elementSettings.dialogType || 'ajax');
+    if (elementSettings.dialogRenderer) {
+      wrapper += '.' + elementSettings.dialogRenderer;
     }
     ajax.options.url += Drupal.ajax.WRAPPER_FORMAT + '=' + wrapper;
 
-    $(ajax.element).on(element_settings.event, function (event) {
+    $(ajax.element).on(elementSettings.event, function (event) {
       if (!drupalSettings.ajaxTrustedUrl[ajax.url] && !Drupal.url.isLocal(ajax.url)) {
         throw new Error(Drupal.t('The callback URL is not local and not trusted: !url', { '!url': ajax.url }));
       }
       return ajax.eventResponse(this, event);
     });
 
-    if (element_settings.keypress) {
+    if (elementSettings.keypress) {
       $(ajax.element).on('keypress', function (event) {
         return ajax.keypressResponse(this, event);
       });
     }
 
-    if (element_settings.prevent) {
-      $(ajax.element).on(element_settings.prevent, false);
+    if (elementSettings.prevent) {
+      $(ajax.element).on(elementSettings.prevent, false);
     }
   };
 
@@ -291,7 +291,7 @@ function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr
     if (event.which === 13 || event.which === 32 && element.type !== 'text' && element.type !== 'textarea' && element.type !== 'tel' && element.type !== 'number') {
       event.preventDefault();
       event.stopPropagation();
-      $(element).trigger(ajax.element_settings.event);
+      $(element).trigger(ajax.elementSettings.event);
     }
   };
 
@@ -336,7 +336,7 @@ function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr
     options.data['ajax_page_state[libraries]'] = pageState.libraries;
   };
 
-  Drupal.Ajax.prototype.beforeSubmit = function (form_values, element, options) {};
+  Drupal.Ajax.prototype.beforeSubmit = function (formValues, element, options) {};
 
   Drupal.Ajax.prototype.beforeSend = function (xmlhttprequest, options) {
     if (this.$form) {
@@ -478,11 +478,11 @@ function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr
       var effect = ajax.getEffect(response);
       var settings = void 0;
 
-      var $new_content_wrapped = $('<div></div>').html(response.data);
-      var $new_content = $new_content_wrapped.contents();
+      var $newContentWrapped = $('<div></div>').html(response.data);
+      var $newContent = $newContentWrapped.contents();
 
-      if ($new_content.length !== 1 || $new_content.get(0).nodeType !== 1) {
-        $new_content = $new_content_wrapped;
+      if ($newContent.length !== 1 || $newContent.get(0).nodeType !== 1) {
+        $newContent = $newContentWrapped;
       }
 
       switch (method) {
@@ -495,23 +495,23 @@ function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr
           Drupal.detachBehaviors($wrapper.get(0), settings);
       }
 
-      $wrapper[method]($new_content);
+      $wrapper[method]($newContent);
 
       if (effect.showEffect !== 'show') {
-        $new_content.hide();
+        $newContent.hide();
       }
 
-      if ($new_content.find('.ajax-new-content').length > 0) {
-        $new_content.find('.ajax-new-content').hide();
-        $new_content.show();
-        $new_content.find('.ajax-new-content')[effect.showEffect](effect.showSpeed);
+      if ($newContent.find('.ajax-new-content').length > 0) {
+        $newContent.find('.ajax-new-content').hide();
+        $newContent.show();
+        $newContent.find('.ajax-new-content')[effect.showEffect](effect.showSpeed);
       } else if (effect.showEffect !== 'show') {
-        $new_content[effect.showEffect](effect.showSpeed);
+        $newContent[effect.showEffect](effect.showSpeed);
       }
 
-      if ($new_content.parents('html').length > 0) {
+      if ($newContent.parents('html').length > 0) {
         settings = response.settings || ajax.settings || drupalSettings;
-        Drupal.attachBehaviors($new_content.get(0), settings);
+        Drupal.attachBehaviors($newContent.get(0), settings);
       }
     },
     remove: function remove(ajax, response, status) {
diff --git a/core/misc/machine-name.es6.js b/core/misc/machine-name.es6.js
index 2695b56d5a..ee7f528092 100644
--- a/core/misc/machine-name.es6.js
+++ b/core/misc/machine-name.es6.js
@@ -86,11 +86,11 @@
         }
       }
 
-      Object.keys(settings.machineName).forEach((source_id) => {
+      Object.keys(settings.machineName).forEach((sourceId) => {
         let machine = '';
-        const options = settings.machineName[source_id];
+        const options = settings.machineName[sourceId];
 
-        const $source = $context.find(source_id).addClass('machine-name-source').once('machine-name');
+        const $source = $context.find(sourceId).addClass('machine-name-source').once('machine-name');
         const $target = $context.find(options.target).addClass('machine-name-target');
         const $suffix = $context.find(options.suffix);
         const $wrapper = $target.closest('.js-form-item');
diff --git a/core/misc/machine-name.js b/core/misc/machine-name.js
index 6e0661bef9..636250f976 100644
--- a/core/misc/machine-name.js
+++ b/core/misc/machine-name.js
@@ -49,11 +49,11 @@
         }
       }
 
-      Object.keys(settings.machineName).forEach(function (source_id) {
+      Object.keys(settings.machineName).forEach(function (sourceId) {
         var machine = '';
-        var options = settings.machineName[source_id];
+        var options = settings.machineName[sourceId];
 
-        var $source = $context.find(source_id).addClass('machine-name-source').once('machine-name');
+        var $source = $context.find(sourceId).addClass('machine-name-source').once('machine-name');
         var $target = $context.find(options.target).addClass('machine-name-target');
         var $suffix = $context.find(options.suffix);
         var $wrapper = $target.closest('.js-form-item');
diff --git a/core/misc/vertical-tabs.es6.js b/core/misc/vertical-tabs.es6.js
index c5980c47ed..61ea218709 100644
--- a/core/misc/vertical-tabs.es6.js
+++ b/core/misc/vertical-tabs.es6.js
@@ -61,7 +61,7 @@
       $(context).find('[data-vertical-tabs-panes]').once('vertical-tabs').each(function () {
         const $this = $(this).addClass('vertical-tabs__panes');
         const focusID = $this.find(':hidden.vertical-tabs__active-tab').val();
-        let tab_focus;
+        let tabFocus;
 
         // Check if there are some details that can be converted to
         // vertical-tabs.
@@ -71,45 +71,45 @@
         }
 
         // Create the tab column.
-        const tab_list = $('<ul class="vertical-tabs__menu"></ul>');
-        $this.wrap('<div class="vertical-tabs clearfix"></div>').before(tab_list);
+        const tabList = $('<ul class="vertical-tabs__menu"></ul>');
+        $this.wrap('<div class="vertical-tabs clearfix"></div>').before(tabList);
 
         // Transform each details into a tab.
         $details.each(function () {
           const $that = $(this);
-          const vertical_tab = new Drupal.verticalTab({
+          const verticalTab = new Drupal.verticalTab({
             title: $that.find('> summary').text(),
             details: $that,
           });
-          tab_list.append(vertical_tab.item);
+          tabList.append(verticalTab.item);
           $that
             .removeClass('collapsed')
             // prop() can't be used on browsers not supporting details element,
             // the style won't apply to them if prop() is used.
             .attr('open', true)
             .addClass('vertical-tabs__pane')
-            .data('verticalTab', vertical_tab);
+            .data('verticalTab', verticalTab);
           if (this.id === focusID) {
-            tab_focus = $that;
+            tabFocus = $that;
           }
         });
 
-        $(tab_list).find('> li').eq(0).addClass('first');
-        $(tab_list).find('> li').eq(-1).addClass('last');
+        $(tabList).find('> li').eq(0).addClass('first');
+        $(tabList).find('> li').eq(-1).addClass('last');
 
-        if (!tab_focus) {
+        if (!tabFocus) {
           // If the current URL has a fragment and one of the tabs contains an
           // element that matches the URL fragment, activate that tab.
           const $locationHash = $this.find(window.location.hash);
           if (window.location.hash && $locationHash.length) {
-            tab_focus = $locationHash.closest('.vertical-tabs__pane');
+            tabFocus = $locationHash.closest('.vertical-tabs__pane');
           }
           else {
-            tab_focus = $this.find('> .vertical-tabs__pane').eq(0);
+            tabFocus = $this.find('> .vertical-tabs__pane').eq(0);
           }
         }
-        if (tab_focus.length) {
-          tab_focus.data('verticalTab').focus();
+        if (tabFocus.length) {
+          tabFocus.data('verticalTab').focus();
         }
       });
     },
diff --git a/core/misc/vertical-tabs.js b/core/misc/vertical-tabs.js
index ea89e85030..18270073cb 100644
--- a/core/misc/vertical-tabs.js
+++ b/core/misc/vertical-tabs.js
@@ -26,42 +26,42 @@
       $(context).find('[data-vertical-tabs-panes]').once('vertical-tabs').each(function () {
         var $this = $(this).addClass('vertical-tabs__panes');
         var focusID = $this.find(':hidden.vertical-tabs__active-tab').val();
-        var tab_focus = void 0;
+        var tabFocus = void 0;
 
         var $details = $this.find('> details');
         if ($details.length === 0) {
           return;
         }
 
-        var tab_list = $('<ul class="vertical-tabs__menu"></ul>');
-        $this.wrap('<div class="vertical-tabs clearfix"></div>').before(tab_list);
+        var tabList = $('<ul class="vertical-tabs__menu"></ul>');
+        $this.wrap('<div class="vertical-tabs clearfix"></div>').before(tabList);
 
         $details.each(function () {
           var $that = $(this);
-          var vertical_tab = new Drupal.verticalTab({
+          var verticalTab = new Drupal.verticalTab({
             title: $that.find('> summary').text(),
             details: $that
           });
-          tab_list.append(vertical_tab.item);
-          $that.removeClass('collapsed').attr('open', true).addClass('vertical-tabs__pane').data('verticalTab', vertical_tab);
+          tabList.append(verticalTab.item);
+          $that.removeClass('collapsed').attr('open', true).addClass('vertical-tabs__pane').data('verticalTab', verticalTab);
           if (this.id === focusID) {
-            tab_focus = $that;
+            tabFocus = $that;
           }
         });
 
-        $(tab_list).find('> li').eq(0).addClass('first');
-        $(tab_list).find('> li').eq(-1).addClass('last');
+        $(tabList).find('> li').eq(0).addClass('first');
+        $(tabList).find('> li').eq(-1).addClass('last');
 
-        if (!tab_focus) {
+        if (!tabFocus) {
           var $locationHash = $this.find(window.location.hash);
           if (window.location.hash && $locationHash.length) {
-            tab_focus = $locationHash.closest('.vertical-tabs__pane');
+            tabFocus = $locationHash.closest('.vertical-tabs__pane');
           } else {
-            tab_focus = $this.find('> .vertical-tabs__pane').eq(0);
+            tabFocus = $this.find('> .vertical-tabs__pane').eq(0);
           }
         }
-        if (tab_focus.length) {
-          tab_focus.data('verticalTab').focus();
+        if (tabFocus.length) {
+          tabFocus.data('verticalTab').focus();
         }
       });
     }
diff --git a/core/modules/block/js/block.admin.es6.js b/core/modules/block/js/block.admin.es6.js
index 86a3e366d6..780ea12e2e 100644
--- a/core/modules/block/js/block.admin.es6.js
+++ b/core/modules/block/js/block.admin.es6.js
@@ -24,7 +24,7 @@
     attach(context, settings) {
       const $input = $('input.block-filter-text').once('block-filter-text');
       const $table = $($input.attr('data-element'));
-      let $filter_rows;
+      let $filterRows;
 
       /**
        * Filters the block list.
@@ -52,7 +52,7 @@
 
         // Filter if the length of the query is at least 2 characters.
         if (query.length >= 2) {
-          $filter_rows.each(toggleBlockEntry);
+          $filterRows.each(toggleBlockEntry);
           Drupal.announce(
             Drupal.formatPlural(
               $table.find('tr:visible').length - 1,
@@ -62,14 +62,14 @@
           );
         }
         else {
-          $filter_rows.each(function (index) {
+          $filterRows.each(function (index) {
             $(this).parent().parent().show();
           });
         }
       }
 
       if ($table.length) {
-        $filter_rows = $table.find('div.block-filter-text-source');
+        $filterRows = $table.find('div.block-filter-text-source');
         $input.on('keyup', debounce(filterBlockList, 200));
       }
     },
diff --git a/core/modules/block/js/block.admin.js b/core/modules/block/js/block.admin.js
index afc9b0ba44..7cafed16ac 100644
--- a/core/modules/block/js/block.admin.js
+++ b/core/modules/block/js/block.admin.js
@@ -10,7 +10,7 @@
     attach: function attach(context, settings) {
       var $input = $('input.block-filter-text').once('block-filter-text');
       var $table = $($input.attr('data-element'));
-      var $filter_rows = void 0;
+      var $filterRows = void 0;
 
       function filterBlockList(e) {
         var query = $(e.target).val().toLowerCase();
@@ -23,17 +23,17 @@
         }
 
         if (query.length >= 2) {
-          $filter_rows.each(toggleBlockEntry);
+          $filterRows.each(toggleBlockEntry);
           Drupal.announce(Drupal.formatPlural($table.find('tr:visible').length - 1, '1 block is available in the modified list.', '@count blocks are available in the modified list.'));
         } else {
-          $filter_rows.each(function (index) {
+          $filterRows.each(function (index) {
             $(this).parent().parent().show();
           });
         }
       }
 
       if ($table.length) {
-        $filter_rows = $table.find('div.block-filter-text-source');
+        $filterRows = $table.find('div.block-filter-text-source');
         $input.on('keyup', debounce(filterBlockList, 200));
       }
     }
diff --git a/core/modules/block/js/block.js b/core/modules/block/js/block.js
index 0b11d543e4..9612dfdbf3 100644
--- a/core/modules/block/js/block.js
+++ b/core/modules/block/js/block.js
@@ -119,12 +119,12 @@
         var select = $(this);
 
         tableDrag.rowObject = new tableDrag.row(row[0]);
-        var region_message = table.find('.region-' + select[0].value + '-message');
-        var region_items = region_message.nextUntil('.region-message, .region-title');
-        if (region_items.length) {
-          region_items.last().after(row);
+        var regionMessage = table.find('.region-' + select[0].value + '-message');
+        var regionItems = regionMessage.nextUntil('.region-message, .region-title');
+        if (regionItems.length) {
+          regionItems.last().after(row);
         } else {
-            region_message.after(row);
+            regionMessage.after(row);
           }
         updateBlockWeights(table, select[0].value);
 
diff --git a/core/modules/color/color.js b/core/modules/color/color.js
index 1b036c3aa1..ee91e56274 100644
--- a/core/modules/color/color.js
+++ b/core/modules/color/color.js
@@ -67,7 +67,7 @@
         Drupal.color.callback(context, settings, form, farb, height, width);
       }
 
-      function shift_color(given, ref1, ref2) {
+      function shiftColor(given, ref1, ref2) {
         var d = void 0;
 
         given = farb.RGBToHSL(farb.unpack(given));
@@ -116,14 +116,14 @@
               if (!locks[j - 1] || $(locks[j - 1]).is('.is-unlocked')) {
                 break;
               }
-              matched = shift_color(color, reference[input.key], reference[inputs[j].key]);
+              matched = shiftColor(color, reference[input.key], reference[inputs[j].key]);
               callback(inputs[j], matched, false);
             }
             for (j = i - 1;; --j) {
               if (!locks[j] || $(locks[j]).is('.is-unlocked')) {
                 break;
               }
-              matched = shift_color(color, reference[input.key], reference[inputs[j].key]);
+              matched = shiftColor(color, reference[input.key], reference[inputs[j].key]);
               callback(inputs[j], matched, false);
             }
 
diff --git a/core/modules/color/preview.es6.js b/core/modules/color/preview.es6.js
index 357a62680b..f5988b382d 100644
--- a/core/modules/color/preview.es6.js
+++ b/core/modules/color/preview.es6.js
@@ -47,20 +47,20 @@
       }
 
       // Set up gradients if there are some.
-      let color_start;
-      let color_end;
+      let colorStart;
+      let colorEnd;
       for (const i in settings.gradients) {
         if (settings.gradients.hasOwnProperty(i)) {
-          color_start = farb.unpack(form.find(`.color-palette input[name="palette[${settings.gradients[i].colors[0]}]"]`).val());
-          color_end = farb.unpack(form.find(`.color-palette input[name="palette[${settings.gradients[i].colors[1]}]"]`).val());
-          if (color_start && color_end) {
+          colorStart = farb.unpack(form.find(`.color-palette input[name="palette[${settings.gradients[i].colors[0]}]"]`).val());
+          colorEnd = farb.unpack(form.find(`.color-palette input[name="palette[${settings.gradients[i].colors[1]}]"]`).val());
+          if (colorStart && colorEnd) {
             delta = [];
-            for (const j in color_start) {
-              if (color_start.hasOwnProperty(j)) {
-                delta[j] = (color_end[j] - color_start[j]) / (settings.gradients[i].vertical ? height[i] : width[i]);
+            for (const j in colorStart) {
+              if (colorStart.hasOwnProperty(j)) {
+                delta[j] = (colorEnd[j] - colorStart[j]) / (settings.gradients[i].vertical ? height[i] : width[i]);
               }
             }
-            accum = color_start;
+            accum = colorStart;
             // Render gradient lines.
             form.find(`#gradient-${i} > div`).each(gradientLineColor);
           }
diff --git a/core/modules/color/preview.js b/core/modules/color/preview.js
index b4bcbcc896..6ca5e32891 100644
--- a/core/modules/color/preview.js
+++ b/core/modules/color/preview.js
@@ -25,20 +25,20 @@
         element.style.backgroundColor = farb.pack(accum);
       }
 
-      var color_start = void 0;
-      var color_end = void 0;
+      var colorStart = void 0;
+      var colorEnd = void 0;
       for (var i in settings.gradients) {
         if (settings.gradients.hasOwnProperty(i)) {
-          color_start = farb.unpack(form.find('.color-palette input[name="palette[' + settings.gradients[i].colors[0] + ']"]').val());
-          color_end = farb.unpack(form.find('.color-palette input[name="palette[' + settings.gradients[i].colors[1] + ']"]').val());
-          if (color_start && color_end) {
+          colorStart = farb.unpack(form.find('.color-palette input[name="palette[' + settings.gradients[i].colors[0] + ']"]').val());
+          colorEnd = farb.unpack(form.find('.color-palette input[name="palette[' + settings.gradients[i].colors[1] + ']"]').val());
+          if (colorStart && colorEnd) {
             delta = [];
-            for (var j in color_start) {
-              if (color_start.hasOwnProperty(j)) {
-                delta[j] = (color_end[j] - color_start[j]) / (settings.gradients[i].vertical ? height[i] : width[i]);
+            for (var j in colorStart) {
+              if (colorStart.hasOwnProperty(j)) {
+                delta[j] = (colorEnd[j] - colorStart[j]) / (settings.gradients[i].vertical ? height[i] : width[i]);
               }
             }
-            accum = color_start;
+            accum = colorStart;
 
             form.find('#gradient-' + i + ' > div').each(gradientLineColor);
           }
diff --git a/core/modules/content_translation/content_translation.admin.es6.js b/core/modules/content_translation/content_translation.admin.es6.js
index 6736be69e5..6c5d0d9945 100644
--- a/core/modules/content_translation/content_translation.admin.es6.js
+++ b/core/modules/content_translation/content_translation.admin.es6.js
@@ -17,11 +17,11 @@
       const $context = $(context);
       const options = drupalSettings.contentTranslationDependentOptions;
       let $fields;
-      let dependent_columns;
+      let dependentColumns;
 
-      function fieldsChangeHandler($fields, dependent_columns) {
+      function fieldsChangeHandler($fields, dependentColumns) {
         return function (e) {
-          Drupal.behaviors.contentTranslationDependentOptions.check($fields, dependent_columns, $(e.target));
+          Drupal.behaviors.contentTranslationDependentOptions.check($fields, dependentColumns, $(e.target));
         };
       }
 
@@ -32,15 +32,15 @@
         for (const field in options.dependent_selectors) {
           if (options.dependent_selectors.hasOwnProperty(field)) {
             $fields = $context.find(`input[name^="${field}"]`);
-            dependent_columns = options.dependent_selectors[field];
+            dependentColumns = options.dependent_selectors[field];
 
-            $fields.on('change', fieldsChangeHandler($fields, dependent_columns));
-            Drupal.behaviors.contentTranslationDependentOptions.check($fields, dependent_columns);
+            $fields.on('change', fieldsChangeHandler($fields, dependentColumns));
+            Drupal.behaviors.contentTranslationDependentOptions.check($fields, dependentColumns);
           }
         }
       }
     },
-    check($fields, dependent_columns, $changed) {
+    check($fields, dependentColumns, $changed) {
       let $element = $changed;
       let column;
 
@@ -50,9 +50,9 @@
 
       // A field that has many different translatable parts can also define one
       // or more columns that require all columns to be translatable.
-      for (const index in dependent_columns) {
-        if (dependent_columns.hasOwnProperty(index)) {
-          column = dependent_columns[index];
+      for (const index in dependentColumns) {
+        if (dependentColumns.hasOwnProperty(index)) {
+          column = dependentColumns[index];
 
           if (!$changed) {
             $element = $fields.filter(filterFieldsList);
diff --git a/core/modules/content_translation/content_translation.admin.js b/core/modules/content_translation/content_translation.admin.js
index 2d524870e9..5066438930 100644
--- a/core/modules/content_translation/content_translation.admin.js
+++ b/core/modules/content_translation/content_translation.admin.js
@@ -11,11 +11,11 @@
       var $context = $(context);
       var options = drupalSettings.contentTranslationDependentOptions;
       var $fields = void 0;
-      var dependent_columns = void 0;
+      var dependentColumns = void 0;
 
-      function fieldsChangeHandler($fields, dependent_columns) {
+      function fieldsChangeHandler($fields, dependentColumns) {
         return function (e) {
-          Drupal.behaviors.contentTranslationDependentOptions.check($fields, dependent_columns, $(e.target));
+          Drupal.behaviors.contentTranslationDependentOptions.check($fields, dependentColumns, $(e.target));
         };
       }
 
@@ -23,15 +23,15 @@
         for (var field in options.dependent_selectors) {
           if (options.dependent_selectors.hasOwnProperty(field)) {
             $fields = $context.find('input[name^="' + field + '"]');
-            dependent_columns = options.dependent_selectors[field];
+            dependentColumns = options.dependent_selectors[field];
 
-            $fields.on('change', fieldsChangeHandler($fields, dependent_columns));
-            Drupal.behaviors.contentTranslationDependentOptions.check($fields, dependent_columns);
+            $fields.on('change', fieldsChangeHandler($fields, dependentColumns));
+            Drupal.behaviors.contentTranslationDependentOptions.check($fields, dependentColumns);
           }
         }
       }
     },
-    check: function check($fields, dependent_columns, $changed) {
+    check: function check($fields, dependentColumns, $changed) {
       var $element = $changed;
       var column = void 0;
 
@@ -39,9 +39,9 @@
         return $(field).val() === column;
       }
 
-      for (var index in dependent_columns) {
-        if (dependent_columns.hasOwnProperty(index)) {
-          column = dependent_columns[index];
+      for (var index in dependentColumns) {
+        if (dependentColumns.hasOwnProperty(index)) {
+          column = dependentColumns[index];
 
           if (!$changed) {
             $element = $fields.filter(filterFieldsList);
diff --git a/core/modules/editor/js/editor.es6.js b/core/modules/editor/js/editor.es6.js
index a882368359..b87e9141fb 100644
--- a/core/modules/editor/js/editor.es6.js
+++ b/core/modules/editor/js/editor.es6.js
@@ -14,10 +14,10 @@
    *   The text area DOM element, if it was found.
    */
   function findFieldForFormatSelector($formatSelector) {
-    const field_id = $formatSelector.attr('data-editor-for');
+    const fieldId = $formatSelector.attr('data-editor-for');
     // This selector will only find text areas in the top-level document. We do
     // not support attaching editors on text areas within iframes.
-    return $(`#${field_id}`).get(0);
+    return $(`#${fieldId}`).get(0);
   }
 
   /**
diff --git a/core/modules/editor/js/editor.js b/core/modules/editor/js/editor.js
index 5ed1679ffc..30177497dd 100644
--- a/core/modules/editor/js/editor.js
+++ b/core/modules/editor/js/editor.js
@@ -7,9 +7,9 @@
 
 (function ($, Drupal, drupalSettings) {
   function findFieldForFormatSelector($formatSelector) {
-    var field_id = $formatSelector.attr('data-editor-for');
+    var fieldId = $formatSelector.attr('data-editor-for');
 
-    return $('#' + field_id).get(0);
+    return $('#' + fieldId).get(0);
   }
 
   function changeTextEditor(field, newFormatID) {
diff --git a/core/modules/menu_ui/menu_ui.es6.js b/core/modules/menu_ui/menu_ui.es6.js
index f384f1113f..9420051922 100644
--- a/core/modules/menu_ui/menu_ui.es6.js
+++ b/core/modules/menu_ui/menu_ui.es6.js
@@ -43,41 +43,41 @@
         // in the form, but play nicely with user permissions and form
         // alterations.
         const $checkbox = $this.find('.js-form-item-menu-enabled input');
-        const $link_title = $context.find('.js-form-item-menu-title input');
+        const $linkTitle = $context.find('.js-form-item-menu-title input');
         const $title = $this.closest('form').find('.js-form-item-title-0-value input');
         // Bail out if we do not have all required fields.
-        if (!($checkbox.length && $link_title.length && $title.length)) {
+        if (!($checkbox.length && $linkTitle.length && $title.length)) {
           return;
         }
         // If there is a link title already, mark it as overridden. The user
         // expects that toggling the checkbox twice will take over the node's
         // title.
-        if ($checkbox.is(':checked') && $link_title.val().length) {
-          $link_title.data('menuLinkAutomaticTitleOverridden', true);
+        if ($checkbox.is(':checked') && $linkTitle.val().length) {
+          $linkTitle.data('menuLinkAutomaticTitleOverridden', true);
         }
         // Whenever the value is changed manually, disable this behavior.
-        $link_title.on('keyup', () => {
-          $link_title.data('menuLinkAutomaticTitleOverridden', true);
+        $linkTitle.on('keyup', () => {
+          $linkTitle.data('menuLinkAutomaticTitleOverridden', true);
         });
         // Global trigger on checkbox (do not fill-in a value when disabled).
         $checkbox.on('change', () => {
           if ($checkbox.is(':checked')) {
-            if (!$link_title.data('menuLinkAutomaticTitleOverridden')) {
-              $link_title.val($title.val());
+            if (!$linkTitle.data('menuLinkAutomaticTitleOverridden')) {
+              $linkTitle.val($title.val());
             }
           }
           else {
-            $link_title.val('');
-            $link_title.removeData('menuLinkAutomaticTitleOverridden');
+            $linkTitle.val('');
+            $linkTitle.removeData('menuLinkAutomaticTitleOverridden');
           }
           $checkbox.closest('.vertical-tabs-pane').trigger('summaryUpdated');
           $checkbox.trigger('formUpdated');
         });
         // Take over any title change.
         $title.on('keyup', () => {
-          if (!$link_title.data('menuLinkAutomaticTitleOverridden') && $checkbox.is(':checked')) {
-            $link_title.val($title.val());
-            $link_title.val($title.val()).trigger('formUpdated');
+          if (!$linkTitle.data('menuLinkAutomaticTitleOverridden') && $checkbox.is(':checked')) {
+            $linkTitle.val($title.val());
+            $linkTitle.val($title.val()).trigger('formUpdated');
           }
         });
       });
diff --git a/core/modules/menu_ui/menu_ui.js b/core/modules/menu_ui/menu_ui.js
index fe0feed9aa..b251b6e450 100644
--- a/core/modules/menu_ui/menu_ui.js
+++ b/core/modules/menu_ui/menu_ui.js
@@ -26,38 +26,38 @@
         var $this = $(this);
 
         var $checkbox = $this.find('.js-form-item-menu-enabled input');
-        var $link_title = $context.find('.js-form-item-menu-title input');
+        var $linkTitle = $context.find('.js-form-item-menu-title input');
         var $title = $this.closest('form').find('.js-form-item-title-0-value input');
 
-        if (!($checkbox.length && $link_title.length && $title.length)) {
+        if (!($checkbox.length && $linkTitle.length && $title.length)) {
           return;
         }
 
-        if ($checkbox.is(':checked') && $link_title.val().length) {
-          $link_title.data('menuLinkAutomaticTitleOverridden', true);
+        if ($checkbox.is(':checked') && $linkTitle.val().length) {
+          $linkTitle.data('menuLinkAutomaticTitleOverridden', true);
         }
 
-        $link_title.on('keyup', function () {
-          $link_title.data('menuLinkAutomaticTitleOverridden', true);
+        $linkTitle.on('keyup', function () {
+          $linkTitle.data('menuLinkAutomaticTitleOverridden', true);
         });
 
         $checkbox.on('change', function () {
           if ($checkbox.is(':checked')) {
-            if (!$link_title.data('menuLinkAutomaticTitleOverridden')) {
-              $link_title.val($title.val());
+            if (!$linkTitle.data('menuLinkAutomaticTitleOverridden')) {
+              $linkTitle.val($title.val());
             }
           } else {
-            $link_title.val('');
-            $link_title.removeData('menuLinkAutomaticTitleOverridden');
+            $linkTitle.val('');
+            $linkTitle.removeData('menuLinkAutomaticTitleOverridden');
           }
           $checkbox.closest('.vertical-tabs-pane').trigger('summaryUpdated');
           $checkbox.trigger('formUpdated');
         });
 
         $title.on('keyup', function () {
-          if (!$link_title.data('menuLinkAutomaticTitleOverridden') && $checkbox.is(':checked')) {
-            $link_title.val($title.val());
-            $link_title.val($title.val()).trigger('formUpdated');
+          if (!$linkTitle.data('menuLinkAutomaticTitleOverridden') && $checkbox.is(':checked')) {
+            $linkTitle.val($title.val());
+            $linkTitle.val($title.val()).trigger('formUpdated');
           }
         });
       });
diff --git a/core/modules/views/js/ajax_view.js b/core/modules/views/js/ajax_view.js
index 67601a121f..d0e21196b9 100644
--- a/core/modules/views/js/ajax_view.js
+++ b/core/modules/views/js/ajax_view.js
@@ -26,22 +26,22 @@
     var selector = '.js-view-dom-id-' + settings.view_dom_id;
     this.$view = $(selector);
 
-    var ajax_path = drupalSettings.views.ajax_path;
+    var ajaxPath = drupalSettings.views.ajaxPath;
 
-    if (ajax_path.constructor.toString().indexOf('Array') !== -1) {
-      ajax_path = ajax_path[0];
+    if (ajaxPath.constructor.toString().indexOf('Array') !== -1) {
+      ajaxPath = ajaxPath[0];
     }
 
     var queryString = window.location.search || '';
     if (queryString !== '') {
       queryString = queryString.slice(1).replace(/q=[^&]+&?|&?render=[^&]+/, '');
       if (queryString !== '') {
-        queryString = (/\?/.test(ajax_path) ? '&' : '?') + queryString;
+        queryString = (/\?/.test(ajaxPath) ? '&' : '?') + queryString;
       }
     }
 
     this.element_settings = {
-      url: ajax_path + queryString,
+      url: ajaxPath + queryString,
       submit: settings,
       setClick: true,
       event: 'click',
@@ -56,12 +56,12 @@
 
     this.$view.filter($.proxy(this.filterNestedViews, this)).once('ajax-pager').each($.proxy(this.attachPagerAjax, this));
 
-    var self_settings = $.extend({}, this.element_settings, {
+    var selfSettings = $.extend({}, this.element_settings, {
       event: 'RefreshView',
       base: this.selector,
       element: this.$view.get(0)
     });
-    this.refreshViewAjax = Drupal.ajax(self_settings);
+    this.refreshViewAjax = Drupal.ajax(selfSettings);
   };
 
   Drupal.views.ajaxView.prototype.attachExposedFormAjax = function () {
@@ -69,11 +69,11 @@
     this.exposedFormAjax = [];
 
     $('input[type=submit], input[type=image]', this.$exposed_form).not('[data-drupal-selector=edit-reset]').each(function (index) {
-      var self_settings = $.extend({}, that.element_settings, {
+      var selfSettings = $.extend({}, that.element_settings, {
         base: $(this).attr('id'),
         element: this
       });
-      that.exposedFormAjax[index] = Drupal.ajax(self_settings);
+      that.exposedFormAjax[index] = Drupal.ajax(selfSettings);
     });
   };
 
@@ -92,12 +92,12 @@
 
     $.extend(viewData, this.settings, Drupal.Views.parseQueryString(href), Drupal.Views.parseViewArgs(href, this.settings.view_base_path));
 
-    var self_settings = $.extend({}, this.element_settings, {
+    var selfSettings = $.extend({}, this.element_settings, {
       submit: viewData,
       base: false,
       element: link
     });
-    this.pagerAjax = Drupal.ajax(self_settings);
+    this.pagerAjax = Drupal.ajax(selfSettings);
   };
 
   Drupal.AjaxCommands.prototype.viewsScrollTop = function (ajax, response) {
diff --git a/core/modules/views_ui/js/ajax.es6.js b/core/modules/views_ui/js/ajax.es6.js
index 73f2b967d8..ab2ed06246 100644
--- a/core/modules/views_ui/js/ajax.es6.js
+++ b/core/modules/views_ui/js/ajax.es6.js
@@ -36,19 +36,19 @@
     // Identify the button that was clicked so that .ajaxSubmit() can use it.
     // We need to do this for both .click() and .mousedown() since JavaScript
     // code might trigger either behavior.
-    const $submit_buttons = $form.find('input[type=submit].js-form-submit, button.js-form-submit').once('views-ajax-submit');
-    $submit_buttons.on('click mousedown', function () {
+    const $submitButtons = $form.find('input[type=submit].js-form-submit, button.js-form-submit').once('views-ajax-submit');
+    $submitButtons.on('click mousedown', function () {
       this.form.clk = this;
     });
     $form.once('views-ajax-submit').each(function () {
       const $form = $(this);
-      const element_settings = {
+      const elementSettings = {
         url: response.url,
         event: 'submit',
         base: $form.attr('id'),
         element: this,
       };
-      const ajaxForm = Drupal.ajax(element_settings);
+      const ajaxForm = Drupal.ajax(elementSettings);
       ajaxForm.$form = $form;
     });
   };
@@ -159,9 +159,9 @@
       $('#views-tabset a').once('views-ajax').on('click', function () {
         const href = $(this).attr('href');
         // Cut of #views-tabset.
-        const display_id = href.substr(11);
+        const displayId = href.substr(11);
         // Set the form element.
-        $('#views-live-preview #preview-display-id').val(display_id);
+        $('#views-live-preview #preview-display-id').val(displayId);
       });
     },
   };
@@ -177,20 +177,20 @@
   Drupal.behaviors.viewsAjax = {
     collapseReplaced: false,
     attach(context, settings) {
-      const base_element_settings = {
+      const baseElementSettings = {
         event: 'click',
         progress: { type: 'fullscreen' },
       };
       // Bind AJAX behaviors to all items showing the class.
       $('a.views-ajax-link', context).once('views-ajax').each(function () {
-        const element_settings = base_element_settings;
-        element_settings.base = $(this).attr('id');
-        element_settings.element = this;
+        const elementSettings = baseElementSettings;
+        elementSettings.base = $(this).attr('id');
+        elementSettings.element = this;
         // Set the URL to go to the anchor.
         if ($(this).attr('href')) {
-          element_settings.url = $(this).attr('href');
+          elementSettings.url = $(this).attr('href');
         }
-        Drupal.ajax(element_settings);
+        Drupal.ajax(elementSettings);
       });
 
       $('div#views-live-preview a')
@@ -200,18 +200,18 @@
             return true;
           }
 
-          const element_settings = base_element_settings;
+          const elementSettings = baseElementSettings;
           // Set the URL to go to the anchor.
-          element_settings.url = $(this).attr('href');
-          if (Drupal.Views.getPath(element_settings.url).substring(0, 21) !== 'admin/structure/views') {
+          elementSettings.url = $(this).attr('href');
+          if (Drupal.Views.getPath(elementSettings.url).substring(0, 21) !== 'admin/structure/views') {
             return true;
           }
 
-          element_settings.wrapper = 'views-preview-wrapper';
-          element_settings.method = 'replaceWith';
-          element_settings.base = $(this).attr('id');
-          element_settings.element = this;
-          Drupal.ajax(element_settings);
+          elementSettings.wrapper = 'views-preview-wrapper';
+          elementSettings.method = 'replaceWith';
+          elementSettings.base = $(this).attr('id');
+          elementSettings.element = this;
+          Drupal.ajax(elementSettings);
         });
 
       // Within a live preview, make exposed widget form buttons re-trigger the
@@ -224,20 +224,20 @@
             this.form.clk = this;
             return true;
           });
-          const element_settings = base_element_settings;
+          const elementSettings = baseElementSettings;
           // Set the URL to go to the anchor.
-          element_settings.url = $(this.form).attr('action');
-          if (Drupal.Views.getPath(element_settings.url).substring(0, 21) !== 'admin/structure/views') {
+          elementSettings.url = $(this.form).attr('action');
+          if (Drupal.Views.getPath(elementSettings.url).substring(0, 21) !== 'admin/structure/views') {
             return true;
           }
 
-          element_settings.wrapper = 'views-preview-wrapper';
-          element_settings.method = 'replaceWith';
-          element_settings.event = 'click';
-          element_settings.base = $(this).attr('id');
-          element_settings.element = this;
+          elementSettings.wrapper = 'views-preview-wrapper';
+          elementSettings.method = 'replaceWith';
+          elementSettings.event = 'click';
+          elementSettings.base = $(this).attr('id');
+          elementSettings.element = this;
 
-          Drupal.ajax(element_settings);
+          Drupal.ajax(elementSettings);
         });
     },
   };
diff --git a/core/modules/views_ui/js/ajax.js b/core/modules/views_ui/js/ajax.js
index 00024f5715..b7b9dcf53b 100644
--- a/core/modules/views_ui/js/ajax.js
+++ b/core/modules/views_ui/js/ajax.js
@@ -14,19 +14,19 @@
   Drupal.AjaxCommands.prototype.viewsSetForm = function (ajax, response, status) {
     var $form = $('.js-views-ui-dialog form');
 
-    var $submit_buttons = $form.find('input[type=submit].js-form-submit, button.js-form-submit').once('views-ajax-submit');
-    $submit_buttons.on('click mousedown', function () {
+    var $submitButtons = $form.find('input[type=submit].js-form-submit, button.js-form-submit').once('views-ajax-submit');
+    $submitButtons.on('click mousedown', function () {
       this.form.clk = this;
     });
     $form.once('views-ajax-submit').each(function () {
       var $form = $(this);
-      var element_settings = {
+      var elementSettings = {
         url: response.url,
         event: 'submit',
         base: $form.attr('id'),
         element: this
       };
-      var ajaxForm = Drupal.ajax(element_settings);
+      var ajaxForm = Drupal.ajax(elementSettings);
       ajaxForm.$form = $form;
     });
   };
@@ -75,9 +75,9 @@
       $('#views-tabset a').once('views-ajax').on('click', function () {
         var href = $(this).attr('href');
 
-        var display_id = href.substr(11);
+        var displayId = href.substr(11);
 
-        $('#views-live-preview #preview-display-id').val(display_id);
+        $('#views-live-preview #preview-display-id').val(displayId);
       });
     }
   };
@@ -85,20 +85,20 @@
   Drupal.behaviors.viewsAjax = {
     collapseReplaced: false,
     attach: function attach(context, settings) {
-      var base_element_settings = {
+      var baseElementSettings = {
         event: 'click',
         progress: { type: 'fullscreen' }
       };
 
       $('a.views-ajax-link', context).once('views-ajax').each(function () {
-        var element_settings = base_element_settings;
-        element_settings.base = $(this).attr('id');
-        element_settings.element = this;
+        var elementSettings = baseElementSettings;
+        elementSettings.base = $(this).attr('id');
+        elementSettings.element = this;
 
         if ($(this).attr('href')) {
-          element_settings.url = $(this).attr('href');
+          elementSettings.url = $(this).attr('href');
         }
-        Drupal.ajax(element_settings);
+        Drupal.ajax(elementSettings);
       });
 
       $('div#views-live-preview a').once('views-ajax').each(function () {
@@ -106,18 +106,18 @@
           return true;
         }
 
-        var element_settings = base_element_settings;
+        var elementSettings = baseElementSettings;
 
-        element_settings.url = $(this).attr('href');
-        if (Drupal.Views.getPath(element_settings.url).substring(0, 21) !== 'admin/structure/views') {
+        elementSettings.url = $(this).attr('href');
+        if (Drupal.Views.getPath(elementSettings.url).substring(0, 21) !== 'admin/structure/views') {
           return true;
         }
 
-        element_settings.wrapper = 'views-preview-wrapper';
-        element_settings.method = 'replaceWith';
-        element_settings.base = $(this).attr('id');
-        element_settings.element = this;
-        Drupal.ajax(element_settings);
+        elementSettings.wrapper = 'views-preview-wrapper';
+        elementSettings.method = 'replaceWith';
+        elementSettings.base = $(this).attr('id');
+        elementSettings.element = this;
+        Drupal.ajax(elementSettings);
       });
 
       $('div#views-live-preview input[type=submit]').once('views-ajax').each(function (event) {
@@ -125,20 +125,20 @@
           this.form.clk = this;
           return true;
         });
-        var element_settings = base_element_settings;
+        var elementSettings = baseElementSettings;
 
-        element_settings.url = $(this.form).attr('action');
-        if (Drupal.Views.getPath(element_settings.url).substring(0, 21) !== 'admin/structure/views') {
+        elementSettings.url = $(this.form).attr('action');
+        if (Drupal.Views.getPath(elementSettings.url).substring(0, 21) !== 'admin/structure/views') {
           return true;
         }
 
-        element_settings.wrapper = 'views-preview-wrapper';
-        element_settings.method = 'replaceWith';
-        element_settings.event = 'click';
-        element_settings.base = $(this).attr('id');
-        element_settings.element = this;
+        elementSettings.wrapper = 'views-preview-wrapper';
+        elementSettings.method = 'replaceWith';
+        elementSettings.event = 'click';
+        elementSettings.base = $(this).attr('id');
+        elementSettings.element = this;
 
-        Drupal.ajax(element_settings);
+        Drupal.ajax(elementSettings);
       });
     }
   };
diff --git a/core/modules/views_ui/js/views-admin.es6.js b/core/modules/views_ui/js/views-admin.es6.js
index 9866f9f7c9..a3b471f0cc 100644
--- a/core/modules/views_ui/js/views-admin.es6.js
+++ b/core/modules/views_ui/js/views-admin.es6.js
@@ -1134,11 +1134,11 @@
         // Closures! :(
         const $context = $(context);
         const $submit = $context.find('[id^=edit-submit]');
-        const old_value = $submit.val();
+        const oldValue = $submit.val();
 
         $submit.once('views-ui-override-button-text')
           .on('mouseup', function () {
-            $(this).val(old_value);
+            $(this).val(oldValue);
             return true;
           });
 
diff --git a/core/modules/views_ui/js/views-admin.js b/core/modules/views_ui/js/views-admin.js
index 032db569a5..1b175d1df3 100644
--- a/core/modules/views_ui/js/views-admin.js
+++ b/core/modules/views_ui/js/views-admin.js
@@ -586,10 +586,10 @@
       $(context).find('[data-drupal-selector="edit-override-dropdown"]').once('views-ui-override-button-text').each(function () {
         var $context = $(context);
         var $submit = $context.find('[id^=edit-submit]');
-        var old_value = $submit.val();
+        var oldValue = $submit.val();
 
         $submit.once('views-ui-override-button-text').on('mouseup', function () {
-          $(this).val(old_value);
+          $(this).val(oldValue);
           return true;
         });
 
diff --git a/core/themes/bartik/color/preview.es6.js b/core/themes/bartik/color/preview.es6.js
index 90d3b421cb..a41f1f2c20 100644
--- a/core/themes/bartik/color/preview.es6.js
+++ b/core/themes/bartik/color/preview.es6.js
@@ -35,10 +35,10 @@
       $colorPreview.find('.color-preview-footer-wrapper').css('background-color', $colorPalette.find('input[name="palette[footer]"]').val());
 
       // CSS3 Gradients.
-      const gradient_start = $colorPalette.find('input[name="palette[top]"]').val();
-      const gradient_end = $colorPalette.find('input[name="palette[bottom]"]').val();
+      const gradientStart = $colorPalette.find('input[name="palette[top]"]').val();
+      const gradientEnd = $colorPalette.find('input[name="palette[bottom]"]').val();
 
-      $colorPreview.find('.color-preview-header').attr('style', `background-color: ${gradient_start}; background-image: -webkit-gradient(linear, 0% 0%, 0% 100%, from(${gradient_start}), to(${gradient_end})); background-image: -moz-linear-gradient(-90deg, ${gradient_start}, ${gradient_end});`);
+      $colorPreview.find('.color-preview-header').attr('style', `background-color: ${gradientStart}; background-image: -webkit-gradient(linear, 0% 0%, 0% 100%, from(${gradientStart}), to(${gradientEnd})); background-image: -moz-linear-gradient(-90deg, ${gradientStart}, ${gradientEnd});`);
 
       $colorPreview.find('.color-preview-site-name').css('color', $colorPalette.find('input[name="palette[titleslogan]"]').val());
     },
diff --git a/core/themes/bartik/color/preview.js b/core/themes/bartik/color/preview.js
index 025bbc9a4e..9ffddc85a9 100644
--- a/core/themes/bartik/color/preview.js
+++ b/core/themes/bartik/color/preview.js
@@ -32,10 +32,10 @@
 
       $colorPreview.find('.color-preview-footer-wrapper').css('background-color', $colorPalette.find('input[name="palette[footer]"]').val());
 
-      var gradient_start = $colorPalette.find('input[name="palette[top]"]').val();
-      var gradient_end = $colorPalette.find('input[name="palette[bottom]"]').val();
+      var gradientStart = $colorPalette.find('input[name="palette[top]"]').val();
+      var gradientEnd = $colorPalette.find('input[name="palette[bottom]"]').val();
 
-      $colorPreview.find('.color-preview-header').attr('style', 'background-color: ' + gradient_start + '; background-image: -webkit-gradient(linear, 0% 0%, 0% 100%, from(' + gradient_start + '), to(' + gradient_end + ')); background-image: -moz-linear-gradient(-90deg, ' + gradient_start + ', ' + gradient_end + ');');
+      $colorPreview.find('.color-preview-header').attr('style', 'background-color: ' + gradientStart + '; background-image: -webkit-gradient(linear, 0% 0%, 0% 100%, from(' + gradientStart + '), to(' + gradientEnd + ')); background-image: -moz-linear-gradient(-90deg, ' + gradientStart + ', ' + gradientEnd + ');');
 
       $colorPreview.find('.color-preview-site-name').css('color', $colorPalette.find('input[name="palette[titleslogan]"]').val());
     }

diff --git a/core/misc/ajax.es6.js b/core/misc/ajax.es6.js
index 2e6fa91d77..5fa9524903 100644
--- a/core/misc/ajax.es6.js
+++ b/core/misc/ajax.es6.js
@@ -28,14 +28,14 @@
   Drupal.behaviors.AJAX = {
     attach(context, settings) {
       function loadAjaxBehavior(base) {
-        const element_settings = settings.ajax[base];
-        if (typeof element_settings.selector === 'undefined') {
-          element_settings.selector = `#${base}`;
+        const elementSettings = settings.ajax[base];
+        if (typeof elementSettings.selector === 'undefined') {
+          elementSettings.selector = `#${base}`;
         }
-        $(element_settings.selector).once('drupal-ajax').each(function () {
-          element_settings.element = this;
-          element_settings.base = base;
-          Drupal.ajax(element_settings);
+        $(elementSettings.selector).once('drupal-ajax').each(function () {
+          elementSettings.element = this;
+          elementSettings.base = base;
+          Drupal.ajax(elementSettings);
         });
       }
 
@@ -48,44 +48,44 @@
 
       // Bind Ajax behaviors to all items showing the class.
       $('.use-ajax').once('ajax').each(function () {
-        const element_settings = {};
+        const elementSettings = {};
         // Clicked links look better with the throbber than the progress bar.
-        element_settings.progress = { type: 'throbber' };
+        elementSettings.progress = { type: 'throbber' };
 
         // For anchor tags, these will go to the target of the anchor rather
         // than the usual location.
         const href = $(this).attr('href');
         if (href) {
-          element_settings.url = href;
-          element_settings.event = 'click';
+          elementSettings.url = href;
+          elementSettings.event = 'click';
         }
-        element_settings.dialogType = $(this).data('dialog-type');
-        element_settings.dialogRenderer = $(this).data('dialog-renderer');
-        element_settings.dialog = $(this).data('dialog-options');
-        element_settings.base = $(this).attr('id');
-        element_settings.element = this;
-        Drupal.ajax(element_settings);
+        elementSettings.dialogType = $(this).data('dialog-type');
+        elementSettings.dialogRenderer = $(this).data('dialog-renderer');
+        elementSettings.dialog = $(this).data('dialog-options');
+        elementSettings.base = $(this).attr('id');
+        elementSettings.element = this;
+        Drupal.ajax(elementSettings);
       });
 
       // This class means to submit the form to the action using Ajax.
       $('.use-ajax-submit').once('ajax').each(function () {
-        const element_settings = {};
+        const elementSettings = {};
 
         // Ajax submits specified in this manner automatically submit to the
         // normal form action.
-        element_settings.url = $(this.form).attr('action');
+        elementSettings.url = $(this.form).attr('action');
         // Form submit button clicks need to tell the form what was clicked so
         // it gets passed in the POST request.
-        element_settings.setClick = true;
+        elementSettings.setClick = true;
         // Form buttons use the 'click' event rather than mousedown.
-        element_settings.event = 'click';
+        elementSettings.event = 'click';
         // Clicked form buttons look better with the throbber than the progress
         // bar.
-        element_settings.progress = { type: 'throbber' };
-        element_settings.base = $(this).attr('id');
-        element_settings.element = this;
+        elementSettings.progress = { type: 'throbber' };
+        elementSettings.base = $(this).attr('id');
+        elementSettings.element = this;
 
-        Drupal.ajax(element_settings);
+        Drupal.ajax(elementSettings);
       });
     },
 
@@ -271,7 +271,7 @@
   /**
    * Settings for an Ajax object.
    *
-   * @typedef {object} Drupal.Ajax~element_settings
+   * @typedef {object} Drupal.Ajax~elementSettings
    *
    * @prop {string} url
    *   Target of the Ajax request.
@@ -325,10 +325,10 @@
    * @param {HTMLElement} [element]
    *   Element parameter of {@link Drupal.Ajax} constructor, element on which
    *   event listeners will be bound.
-   * @param {Drupal.Ajax~element_settings} element_settings
+   * @param {Drupal.Ajax~elementSettings} elementSettings
    *   Settings for this Ajax object.
    */
-  Drupal.Ajax = function (base, element, element_settings) {
+  Drupal.Ajax = function (base, element, elementSettings) {
     const defaults = {
       event: element ? 'mousedown' : null,
       keypress: true,
@@ -345,7 +345,7 @@
       },
     };
 
-    $.extend(this, defaults, element_settings);
+    $.extend(this, defaults, elementSettings);
 
     /**
      * @type {Drupal.AjaxCommands}
@@ -374,9 +374,9 @@
     this.element = element;
 
     /**
-     * @type {Drupal.Ajax~element_settings}
+     * @type {Drupal.Ajax~elementSettings}
      */
-    this.element_settings = element_settings;
+    this.elementSettings = elementSettings;
 
     // If there isn't a form, jQuery.ajax() will be used instead, allowing us to
     // bind Ajax to links as well.
@@ -457,12 +457,12 @@
     ajax.options = {
       url: ajax.url,
       data: ajax.submit,
-      beforeSerialize(element_settings, options) {
-        return ajax.beforeSerialize(element_settings, options);
+      beforeSerialize(elementSettings, options) {
+        return ajax.beforeSerialize(elementSettings, options);
       },
-      beforeSubmit(form_values, element_settings, options) {
+      beforeSubmit(formValues, elementSettings, options) {
         ajax.ajaxing = true;
-        return ajax.beforeSubmit(form_values, element_settings, options);
+        return ajax.beforeSubmit(formValues, elementSettings, options);
       },
       beforeSend(xmlhttprequest, options) {
         ajax.ajaxing = true;
@@ -504,8 +504,8 @@
       type: 'POST',
     };
 
-    if (element_settings.dialog) {
-      ajax.options.data.dialogOptions = element_settings.dialog;
+    if (elementSettings.dialog) {
+      ajax.options.data.dialogOptions = elementSettings.dialog;
     }
 
     // Ensure that we have a valid URL by adding ? when no query parameter is
@@ -517,15 +517,15 @@
       ajax.options.url += '&';
     }
     // If this element has a dialog type use if for the wrapper if not use 'ajax'.
-    let wrapper = `drupal_${(element_settings.dialogType || 'ajax')}`;
-    if (element_settings.dialogRenderer) {
-      wrapper += `.${element_settings.dialogRenderer}`;
+    let wrapper = `drupal_${(elementSettings.dialogType || 'ajax')}`;
+    if (elementSettings.dialogRenderer) {
+      wrapper += `.${elementSettings.dialogRenderer}`;
     }
     ajax.options.url += `${Drupal.ajax.WRAPPER_FORMAT}=${wrapper}`;
 
 
     // Bind the ajaxSubmit function to the element event.
-    $(ajax.element).on(element_settings.event, function (event) {
+    $(ajax.element).on(elementSettings.event, function (event) {
       if (!drupalSettings.ajaxTrustedUrl[ajax.url] && !Drupal.url.isLocal(ajax.url)) {
         throw new Error(Drupal.t('The callback URL is not local and not trusted: !url', { '!url': ajax.url }));
       }
@@ -535,7 +535,7 @@
     // If necessary, enable keyboard submission so that Ajax behaviors
     // can be triggered through keyboard input as well as e.g. a mousedown
     // action.
-    if (element_settings.keypress) {
+    if (elementSettings.keypress) {
       $(ajax.element).on('keypress', function (event) {
         return ajax.keypressResponse(this, event);
       });
@@ -544,8 +544,8 @@
     // If necessary, prevent the browser default action of an additional event.
     // For example, prevent the browser default action of a click, even if the
     // Ajax behavior binds to mousedown.
-    if (element_settings.prevent) {
-      $(ajax.element).on(element_settings.prevent, false);
+    if (elementSettings.prevent) {
+      $(ajax.element).on(elementSettings.prevent, false);
     }
   };
 
@@ -631,7 +631,7 @@
       element.type !== 'textarea' && element.type !== 'tel' && element.type !== 'number')) {
       event.preventDefault();
       event.stopPropagation();
-      $(element).trigger(ajax.element_settings.event);
+      $(element).trigger(ajax.elementSettings.event);
     }
   };
 
@@ -694,7 +694,7 @@
    * before field data is collected.
    *
    * @param {object} [element]
-   *   Ajax object's `element_settings`.
+   *   Ajax object's `elementSettings`.
    * @param {object} options
    *   jQuery.ajax options.
    */
@@ -726,14 +726,14 @@
   /**
    * Modify form values prior to form submission.
    *
-   * @param {Array.<object>} form_values
+   * @param {Array.<object>} formValues
    *   Processed form values.
    * @param {jQuery} element
    *   The form node as a jQuery object.
    * @param {object} options
    *   jQuery.ajax options.
    */
-  Drupal.Ajax.prototype.beforeSubmit = function (form_values, element, options) {
+  Drupal.Ajax.prototype.beforeSubmit = function (formValues, element, options) {
     // This function is left empty to make it simple to override for modules
     // that wish to add functionality here.
   };
@@ -899,9 +899,9 @@
    * @param {object} response
    *   Drupal Ajax response.
    * @param {string} [response.effect]
    *   Override the default value of {@link Drupal.Ajax#element_settings}.
    * @param {string|number} [response.speed]
    *   Override the default value of {@link Drupal.Ajax#element_settings}.
    *
    * @return {object}
    *   Returns an object with `showEffect`, `hideEffect` and `showSpeed`
@@ -1023,11 +1023,11 @@
       // $(response.data) as new HTML rather than a CSS selector. Also, if
       // response.data contains top-level text nodes, they get lost with either
       // $(response.data) or $('<div></div>').replaceWith(response.data).
-      const $new_content_wrapped = $('<div></div>').html(response.data);
-      let $new_content = $new_content_wrapped.contents();
+      const $newContentWrapped = $('<div></div>').html(response.data);
+      let $newContent = $newContentWrapped.contents();
 
       // For legacy reasons, the effects processing code assumes that
       // $new_content consists of a single top-level element. Also, it has not
       // been sufficiently tested whether attachBehaviors() can be successfully
       // called with a context object that includes top-level text nodes.
       // However, to give developers full control of the HTML appearing in the
@@ -1037,8 +1037,8 @@
       // of a single top-level element, and only use the container <div> created
       // above when it doesn't. For more information, please see
       // https://www.drupal.org/node/736066.
-      if ($new_content.length !== 1 || $new_content.get(0).nodeType !== 1) {
-        $new_content = $new_content_wrapped;
+      if ($newContent.length !== 1 || $newContent.get(0).nodeType !== 1) {
+        $newContent = $newContentWrapped;
       }
 
       // If removing content from the wrapper, detach behaviors first.
@@ -1053,31 +1053,31 @@
       }
 
       // Add the new content to the page.
-      $wrapper[method]($new_content);
+      $wrapper[method]($newContent);
 
       // Immediately hide the new content if we're using any effects.
       if (effect.showEffect !== 'show') {
-        $new_content.hide();
+        $newContent.hide();
       }
 
       // Determine which effect to use and what content will receive the
       // effect, then show the new content.
-      if ($new_content.find('.ajax-new-content').length > 0) {
-        $new_content.find('.ajax-new-content').hide();
-        $new_content.show();
-        $new_content.find('.ajax-new-content')[effect.showEffect](effect.showSpeed);
+      if ($newContent.find('.ajax-new-content').length > 0) {
+        $newContent.find('.ajax-new-content').hide();
+        $newContent.show();
+        $newContent.find('.ajax-new-content')[effect.showEffect](effect.showSpeed);
       }
       else if (effect.showEffect !== 'show') {
-        $new_content[effect.showEffect](effect.showSpeed);
+        $newContent[effect.showEffect](effect.showSpeed);
       }
 
       // Attach all JavaScript behaviors to the new content, if it was
       // successfully added to the page, this if statement allows
       // `#ajax['wrapper']` to be optional.
-      if ($new_content.parents('html').length > 0) {
+      if ($newContent.parents('html').length > 0) {
         // Apply any settings from the returned JSON if available.
         settings = response.settings || ajax.settings || drupalSettings;
-        Drupal.attachBehaviors($new_content.get(0), settings);
+        Drupal.attachBehaviors($newContent.get(0), settings);
       }
     },
 
@@ -899,9 +899,9 @@
    *   Drupal Ajax response.
    * @param {string} [response.effect]
-   *   Override the default value of {@link Drupal.Ajax#element_settings}.
+   *   Override the default value of {@link Drupal.Ajax#elementSettings}.
    * @param {string|number} [response.speed]
@@ -899,9 +899,9 @@
    * @param {string|number} [response.speed]
-   *   Override the default value of {@link Drupal.Ajax#element_settings}.
+   *   Override the default value of {@link Drupal.Ajax#elementSettings}.
    *
    * @return {object}
@@ -1023,11 +1023,11 @@
 
       // For legacy reasons, the effects processing code assumes that
-      // $new_content consists of a single top-level element. Also, it has not
+      // $newContent consists of a single top-level element. Also, it has not
       // been sufficiently tested whether attachBehaviors() can be successfully
       // called with a context object that includes top-level text nodes.
diff --git a/core/modules/block/js/block.es6.js b/core/modules/block/js/block.es6.js
index 3d1802a277..0bde2add24 100644
--- a/core/modules/block/js/block.es6.js
+++ b/core/modules/block/js/block.es6.js
@@ -195,14 +195,14 @@
           // Find the correct region and insert the row as the last in the
           // region.
           tableDrag.rowObject = new tableDrag.row(row[0]);
-          const region_message = table.find(`.region-${select[0].value}-message`);
-          const region_items = region_message.nextUntil('.region-message, .region-title');
-          if (region_items.length) {
-            region_items.last().after(row);
+          const regionMessage = table.find(`.region-${select[0].value}-message`);
+          const regionItems = regionMessage.nextUntil('.region-message, .region-title');
+          if (regionItems.length) {
+            regionItems.last().after(row);
           }
           // We found that region_message is the last row.
           else {
-            region_message.after(row);
+            regionMessage.after(row);
           }
           updateBlockWeights(table, select[0].value);
           // Modify empty regions with added or removed fields.
@@ -195,14 +195,14 @@
           }
-          // We found that region_message is the last row.
+          // We found that regionMessage is the last row.
           else {
diff --git a/core/modules/color/color.es6.js b/core/modules/color/color.es6.js
index 5a514e564c..109bfa1a2c 100644
--- a/core/modules/color/color.es6.js
+++ b/core/modules/color/color.es6.js
@@ -91,10 +91,10 @@
        * This algorithm ensures relative ordering on the saturation and
        * luminance axes is preserved, and performs a simple hue shift.
        *
        * It is also symmetrical. If: shift_color(c, a, b) === d, then
        * shift_color(d, b, a) === c.
        *
-       * @function Drupal.color~shift_color
+       * @function Drupal.color~shiftColor
        *
        * @param {string} given
        *   A hex color code to shift.
@@ -106,7 +106,7 @@
        * @return {string}
        *   A hex color, shifted.
        */
-      function shift_color(given, ref1, ref2) {
+      function shiftColor(given, ref1, ref2) {
         let d;
         // Convert to HSL.
         given = farb.RGBToHSL(farb.unpack(given));
@@ -177,14 +177,14 @@
               if (!locks[j - 1] || $(locks[j - 1]).is('.is-unlocked')) {
                 break;
               }
-              matched = shift_color(color, reference[input.key], reference[inputs[j].key]);
+              matched = shiftColor(color, reference[input.key], reference[inputs[j].key]);
               callback(inputs[j], matched, false);
             }
             for (j = i - 1; ; --j) {
               if (!locks[j] || $(locks[j]).is('.is-unlocked')) {
                 break;
               }
-              matched = shift_color(color, reference[input.key], reference[inputs[j].key]);
+              matched = shiftColor(color, reference[input.key], reference[inputs[j].key]);
               callback(inputs[j], matched, false);
             }
 
@@ -91,10 +91,10 @@
        * luminance axes is preserved, and performs a simple hue shift.
        *
-       * It is also symmetrical. If: shift_color(c, a, b) === d, then
-       * shift_color(d, b, a) === c.
+       * It is also symmetrical. If: shiftColor(c, a, b) === d, then
+       * shiftColor(d, b, a) === c.
        *
diff --git a/core/modules/views/js/ajax_view.es6.js b/core/modules/views/js/ajax_view.es6.js
index df2c4da639..42e3c1dd13 100644
--- a/core/modules/views/js/ajax_view.es6.js
+++ b/core/modules/views/js/ajax_view.es6.js
@@ -49,12 +49,12 @@
     this.$view = $(selector);
 
     // Retrieve the path to use for views' ajax.
-    let ajax_path = drupalSettings.views.ajax_path;
+    let ajaxPath = drupalSettings.views.ajaxPath;
 
     // If there are multiple views this might've ended up showing up multiple
     // times.
-    if (ajax_path.constructor.toString().indexOf('Array') !== -1) {
-      ajax_path = ajax_path[0];
+    if (ajaxPath.constructor.toString().indexOf('Array') !== -1) {
+      ajaxPath = ajaxPath[0];
     }
 
     // Check if there are any GET parameters to send to views.
@@ -63,14 +63,14 @@
       // Remove the question mark and Drupal path component if any.
       queryString = queryString.slice(1).replace(/q=[^&]+&?|&?render=[^&]+/, '');
       if (queryString !== '') {
         // If there is a '?' in ajax_path, clean url are on and & should be
         // used to add parameters.
-        queryString = ((/\?/.test(ajax_path)) ? '&' : '?') + queryString;
+        queryString = ((/\?/.test(ajaxPath)) ? '&' : '?') + queryString;
       }
     }
 
     this.element_settings = {
-      url: ajax_path + queryString,
+      url: ajaxPath + queryString,
       submit: settings,
       setClick: true,
       event: 'click',
@@ -97,12 +97,12 @@
     // @code
     // $('.view-name').trigger('RefreshView');
     // @endcode
-    const self_settings = $.extend({}, this.element_settings, {
+    const selfSettings = $.extend({}, this.element_settings, {
       event: 'RefreshView',
       base: this.selector,
       element: this.$view.get(0),
     });
-    this.refreshViewAjax = Drupal.ajax(self_settings);
+    this.refreshViewAjax = Drupal.ajax(selfSettings);
   };
 
   /**
@@ -114,11 +114,11 @@
     // Exclude the reset buttons so no AJAX behaviours are bound. Many things
     // break during the form reset phase if using AJAX.
     $('input[type=submit], input[type=image]', this.$exposed_form).not('[data-drupal-selector=edit-reset]').each(function (index) {
-      const self_settings = $.extend({}, that.element_settings, {
+      const selfSettings = $.extend({}, that.element_settings, {
         base: $(this).attr('id'),
         element: this,
       });
-      that.exposedFormAjax[index] = Drupal.ajax(self_settings);
+      that.exposedFormAjax[index] = Drupal.ajax(selfSettings);
     });
   };
 
@@ -162,12 +162,12 @@
       Drupal.Views.parseViewArgs(href, this.settings.view_base_path),
     );
 
-    const self_settings = $.extend({}, this.element_settings, {
+    const selfSettings = $.extend({}, this.element_settings, {
       submit: viewData,
       base: false,
       element: link,
     });
-    this.pagerAjax = Drupal.ajax(self_settings);
+    this.pagerAjax = Drupal.ajax(selfSettings);
   };
 
   /**
@@ -63,14 +63,14 @@
       queryString = queryString.slice(1).replace(/q=[^&]+&?|&?render=[^&]+/, '');
       if (queryString !== '') {
-        // If there is a '?' in ajax_path, clean url are on and & should be
+        // If there is a '?' in ajaxPath, clean url are on and & should be
         // used to add parameters.